import { type Options, type SortableEvent } from 'sortablejs';
import type Sortable from 'sortablejs';
import type { Ref } from 'vue';
import type { RefOrElement, RefOrValue } from './types';
type SortableMethod = 'closest' | 'save' | 'toArray' | 'destroy' | 'option';
export interface UseDraggableReturn extends Pick<Sortable, SortableMethod> {
    /**
     * Start the sortable.
     * @param {HTMLElement} target - The target element to be sorted.
     * @default By default the root element of the VueDraggablePlus instance is used
     */
    start: (target?: HTMLElement) => void;
    pause: () => void;
    resume: () => void;
}
export interface UseDraggableOptions<T> extends Options {
    clone?: (element: T) => T;
    immediate?: boolean;
    customUpdate?: (event: SortableEvent) => void;
}
export interface UseDraggableParams<T> {
    el: RefOrElement;
    list: Ref<T[]>;
    options?: RefOrValue<UseDraggableOptions<T>>;
}
/**
 * A custom Composition API utility that allows you to drag and drop elements in lists.
 * @param {UseDraggableParams<T>} params - The parameters object containing:
 *   @param {Ref<HTMLElement | null | undefined> | string} el - The element or selector string for the draggable container.
 *   @param {Ref<T[]> | undefined} list - Optional. A ref to the array of items to be draggable.
 *   @param {RefOrValue<UseDraggableOptions<T>> | undefined} options - Optional. The configuration options for draggable behavior.
 * @returns {UseDraggableReturn} - An object containing methods and properties to control and interact with the draggable feature.
 */
export declare function useDraggable<T>({ el, list, options }: UseDraggableParams<T>): UseDraggableReturn;
export {};
