import { Fn } from '../types';
export declare function moveArrayElement<T>(array: T[], from: number, to: number): T[];
/**
 * Convert a hyphen-delimited string to camelCase.
 * @param {string} str
 * @returns {string}
 */
export declare function camelize(str: string): string;
/**
 * Convert an object's keys from hyphen-delimited to camelCase.
 * @param {Record<string, any>} object
 * @returns {Record<string, any>}
 */
export declare function objectMap(object: Record<any, any>): Record<string, any>;
/**
 * Removes an element from an array.
 * @param {T[]} array
 * @param {number} index
 * @returns {T[]}
 */
export declare function removeElement<T>(array: T[], index: number): T[] | undefined;
/**
 * Inserts an element into an array.
 * @param {T[]} array
 * @param {number} index
 * @param element
 */
export declare function insertElement<T>(array: T[], index: number, element: any): T[] | undefined;
/**
 * If the value is undefined, return true, otherwise return false.
 * @param {any} value - any
 * @returns {value is undefined}
 */
export declare function isUndefined(value: any): value is undefined;
/**
 * If the value is string, return true, otherwise return false.
 * @param value
 * @returns {value is string}
 */
export declare function isString(value: any): value is string;
/**
 * It takes a function and returns a function that executes the original function and then executes the second function.
 * @param {Function} fn - The function to be executed
 * @param {Function} afterFn - The function to be executed after the original function.
 * @param {any} [ctx=null] - The context of the function.
 * @returns {Function}
 */
export declare function mergeExecuted<T extends (...args: []) => any>(fn: T, afterFn: T, ctx?: any): (...args: any[]) => any;
/**
 * Merge the options and events.
 * @param {Record<string, any>} options
 * @param {Record<string, any>} events
 * @returns {Record<string, any>}
 */
export declare function mergeOptionsEvents(options: Record<string, any>, events: Record<string, any>): {
    [x: string]: any;
};
export declare function isHTMLElement(el: any): el is HTMLElement;
/**
 * @param obj
 * @param fn
 */
export declare function forEachObject<T extends Record<string, any>>(obj: T, fn: (key: keyof T, value: T[keyof T]) => void): void;
/**
 * copied from vueuse: https://github.com/vueuse/vueuse/blob/main/packages/shared/tryOnUnmounted/index.ts
 * Call onUnmounted() if it's inside a component lifecycle, if not, do nothing
 * @param fn
 */
export declare function tryOnUnmounted(fn: Fn): void;
/**
 * copied from vueuse:https://github.com/vueuse/vueuse/blob/main/packages/shared/tryOnMounted/index.ts
 * Call onMounted() if it's inside a component lifecycle, if not, just call the function
 * @param fn
 */
export declare function tryOnMounted(fn: Fn): void;
